# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/webhook/webhook_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/webhook/webhook_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.webhook import webhook_pb2 as eolymp_dot_webhook_dot_webhook__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/webhook/webhook_service.proto\x12\x0e\x65olymp.webhook\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/webhook/webhook.proto\">\n\x12\x43reateWebhookInput\x12(\n\x07webhook\x18\x01 \x01(\x0b\x32\x17.eolymp.webhook.Webhook\")\n\x13\x43reateWebhookOutput\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\"\x80\x01\n\x12UpdateWebhookInput\x12,\n\x05patch\x18\x01 \x03(\x0e\x32\x1d.eolymp.webhook.Webhook.Patch\x12\x12\n\nwebhook_id\x18\x02 \x01(\t\x12(\n\x07webhook\x18\x03 \x01(\x0b\x32\x17.eolymp.webhook.Webhook\"\x15\n\x13UpdateWebhookOutput\"(\n\x12\x44\x65leteWebhookInput\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteWebhookOutput\"*\n\x14\x44\x65scribeWebhookInput\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\"A\n\x15\x44\x65scribeWebhookOutput\x12(\n\x07webhook\x18\x01 \x01(\x0b\x32\x17.eolymp.webhook.Webhook\"1\n\x11ListWebhooksInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\"K\n\x12ListWebhooksOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.webhook.Webhook\"&\n\x10TestWebhookInput\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\"5\n\x11TestWebhookOutput\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x10\n\x08response\x18\x02 \x01(\t2\xe0\x07\n\x0eWebhookService\x12\x97\x01\n\rCreateWebhook\x12\".eolymp.webhook.CreateWebhookInput\x1a#.eolymp.webhook.CreateWebhookOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15webhook:webhook:write\x82\xd3\xe4\x93\x02\x0b\"\t/webhooks\x12\xa4\x01\n\rUpdateWebhook\x12\".eolymp.webhook.UpdateWebhookInput\x1a#.eolymp.webhook.UpdateWebhookOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15webhook:webhook:write\x82\xd3\xe4\x93\x02\x18\"\x16/webhooks/{webhook_id}\x12\xa4\x01\n\rDeleteWebhook\x12\".eolymp.webhook.DeleteWebhookInput\x1a#.eolymp.webhook.DeleteWebhookOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15webhook:webhook:write\x82\xd3\xe4\x93\x02\x18*\x16/webhooks/{webhook_id}\x12\xa9\x01\n\x0f\x44\x65scribeWebhook\x12$.eolymp.webhook.DescribeWebhookInput\x1a%.eolymp.webhook.DescribeWebhookOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14webhook:webhook:read\x82\xd3\xe4\x93\x02\x18\x12\x16/webhooks/{webhook_id}\x12\x93\x01\n\x0cListWebhooks\x12!.eolymp.webhook.ListWebhooksInput\x1a\".eolymp.webhook.ListWebhooksOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14webhook:webhook:read\x82\xd3\xe4\x93\x02\x0b\x12\t/webhooks\x12\xa3\x01\n\x0bTestWebhook\x12 .eolymp.webhook.TestWebhookInput\x1a!.eolymp.webhook.TestWebhookOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15webhook:webhook:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/webhooks/{webhook_id}/testB1Z/github.com/eolymp/go-sdk/eolymp/webhook;webhookb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.webhook.webhook_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/webhook;webhook'
  _globals['_WEBHOOKSERVICE'].methods_by_name['CreateWebhook']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['CreateWebhook']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025webhook:webhook:write\202\323\344\223\002\013\"\t/webhooks'
  _globals['_WEBHOOKSERVICE'].methods_by_name['UpdateWebhook']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['UpdateWebhook']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025webhook:webhook:write\202\323\344\223\002\030\"\026/webhooks/{webhook_id}'
  _globals['_WEBHOOKSERVICE'].methods_by_name['DeleteWebhook']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['DeleteWebhook']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025webhook:webhook:write\202\323\344\223\002\030*\026/webhooks/{webhook_id}'
  _globals['_WEBHOOKSERVICE'].methods_by_name['DescribeWebhook']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['DescribeWebhook']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024webhook:webhook:read\202\323\344\223\002\030\022\026/webhooks/{webhook_id}'
  _globals['_WEBHOOKSERVICE'].methods_by_name['ListWebhooks']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['ListWebhooks']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024webhook:webhook:read\202\323\344\223\002\013\022\t/webhooks'
  _globals['_WEBHOOKSERVICE'].methods_by_name['TestWebhook']._loaded_options = None
  _globals['_WEBHOOKSERVICE'].methods_by_name['TestWebhook']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025webhook:webhook:write\202\323\344\223\002\035\"\033/webhooks/{webhook_id}/test'
  _globals['_CREATEWEBHOOKINPUT']._serialized_start=185
  _globals['_CREATEWEBHOOKINPUT']._serialized_end=247
  _globals['_CREATEWEBHOOKOUTPUT']._serialized_start=249
  _globals['_CREATEWEBHOOKOUTPUT']._serialized_end=290
  _globals['_UPDATEWEBHOOKINPUT']._serialized_start=293
  _globals['_UPDATEWEBHOOKINPUT']._serialized_end=421
  _globals['_UPDATEWEBHOOKOUTPUT']._serialized_start=423
  _globals['_UPDATEWEBHOOKOUTPUT']._serialized_end=444
  _globals['_DELETEWEBHOOKINPUT']._serialized_start=446
  _globals['_DELETEWEBHOOKINPUT']._serialized_end=486
  _globals['_DELETEWEBHOOKOUTPUT']._serialized_start=488
  _globals['_DELETEWEBHOOKOUTPUT']._serialized_end=509
  _globals['_DESCRIBEWEBHOOKINPUT']._serialized_start=511
  _globals['_DESCRIBEWEBHOOKINPUT']._serialized_end=553
  _globals['_DESCRIBEWEBHOOKOUTPUT']._serialized_start=555
  _globals['_DESCRIBEWEBHOOKOUTPUT']._serialized_end=620
  _globals['_LISTWEBHOOKSINPUT']._serialized_start=622
  _globals['_LISTWEBHOOKSINPUT']._serialized_end=671
  _globals['_LISTWEBHOOKSOUTPUT']._serialized_start=673
  _globals['_LISTWEBHOOKSOUTPUT']._serialized_end=748
  _globals['_TESTWEBHOOKINPUT']._serialized_start=750
  _globals['_TESTWEBHOOKINPUT']._serialized_end=788
  _globals['_TESTWEBHOOKOUTPUT']._serialized_start=790
  _globals['_TESTWEBHOOKOUTPUT']._serialized_end=843
  _globals['_WEBHOOKSERVICE']._serialized_start=846
  _globals['_WEBHOOKSERVICE']._serialized_end=1838
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/wellknown/expression.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/wellknown/expression.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/wellknown/expression.proto\x12\x10\x65olymp.wellknown\x1a\x1fgoogle/protobuf/timestamp.proto\"z\n\x0c\x45xpressionID\x12/\n\x02is\x18\x01 \x01(\x0e\x32#.eolymp.wellknown.ExpressionID.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"\xca\x01\n\rExpressionInt\x12\x30\n\x02is\x18\x01 \x01(\x0e\x32$.eolymp.wellknown.ExpressionInt.Type\x12\r\n\x05value\x18\x02 \x01(\x05\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\xce\x01\n\x0f\x45xpressionFloat\x12\x32\n\x02is\x18\x01 \x01(\x0e\x32&.eolymp.wellknown.ExpressionFloat.Type\x12\r\n\x05value\x18\x02 \x01(\x02\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\xa0\x01\n\x10\x45xpressionString\x12\x33\n\x02is\x18\x01 \x01(\x0e\x32\'.eolymp.wellknown.ExpressionString.Type\x12\r\n\x05value\x18\x02 \x01(\t\"H\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x0e\n\nCONTAINING\x10\x03\x12\x0c\n\x08STARTING\x10\x04\"~\n\x0e\x45xpressionEnum\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionEnum.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"o\n\x0e\x45xpressionBool\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionBool.Type\x12\r\n\x05value\x18\x02 \x01(\x08\"\x1b\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\"\xf2\x01\n\x13\x45xpressionTimestamp\x12\x36\n\x02is\x18\x01 \x01(\x0e\x32*.eolymp.wellknown.ExpressionTimestamp.Type\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\x42\x35Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknownb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.wellknown.expression_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknown'
  _globals['_EXPRESSIONID']._serialized_start=88
  _globals['_EXPRESSIONID']._serialized_end=210
  _globals['_EXPRESSIONID_TYPE']._serialized_start=168
  _globals['_EXPRESSIONID_TYPE']._serialized_end=210
  _globals['_EXPRESSIONINT']._serialized_start=213
  _globals['_EXPRESSIONINT']._serialized_end=415
  _globals['_EXPRESSIONINT_TYPE']._serialized_start=295
  _globals['_EXPRESSIONINT_TYPE']._serialized_end=415
  _globals['_EXPRESSIONFLOAT']._serialized_start=418
  _globals['_EXPRESSIONFLOAT']._serialized_end=624
  _globals['_EXPRESSIONFLOAT_TYPE']._serialized_start=295
  _globals['_EXPRESSIONFLOAT_TYPE']._serialized_end=415
  _globals['_EXPRESSIONSTRING']._serialized_start=627
  _globals['_EXPRESSIONSTRING']._serialized_end=787
  _globals['_EXPRESSIONSTRING_TYPE']._serialized_start=715
  _globals['_EXPRESSIONSTRING_TYPE']._serialized_end=787
  _globals['_EXPRESSIONENUM']._serialized_start=789
  _globals['_EXPRESSIONENUM']._serialized_end=915
  _globals['_EXPRESSIONENUM_TYPE']._serialized_start=168
  _globals['_EXPRESSIONENUM_TYPE']._serialized_end=210
  _globals['_EXPRESSIONBOOL']._serialized_start=917
  _globals['_EXPRESSIONBOOL']._serialized_end=1028
  _globals['_EXPRESSIONBOOL_TYPE']._serialized_start=168
  _globals['_EXPRESSIONBOOL_TYPE']._serialized_end=195
  _globals['_EXPRESSIONTIMESTAMP']._serialized_start=1031
  _globals['_EXPRESSIONTIMESTAMP']._serialized_end=1273
  _globals['_EXPRESSIONTIMESTAMP_TYPE']._serialized_start=295
  _globals['_EXPRESSIONTIMESTAMP_TYPE']._serialized_end=415
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.commerce import invoice_pb2 as _invoice_pb2
from eolymp.universe import billing_pb2 as _billing_pb2
from eolymp.universe import plan_pb2 as _plan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeBillingInformationInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeBillingInformationOutput(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _billing_pb2.Billing.Information
    def __init__(self, info: _Optional[_Union[_billing_pb2.Billing.Information, _Mapping]] = ...) -> None: ...

class UpdateBillingInformationInput(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _billing_pb2.Billing.Information
    def __init__(self, info: _Optional[_Union[_billing_pb2.Billing.Information, _Mapping]] = ...) -> None: ...

class UpdateBillingInformationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeSubscriptionInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeSubscriptionOutput(_message.Message):
    __slots__ = ("current", "upcoming")
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    UPCOMING_FIELD_NUMBER: _ClassVar[int]
    current: _billing_pb2.Billing.Subscription
    upcoming: _billing_pb2.Billing.Subscription
    def __init__(self, current: _Optional[_Union[_billing_pb2.Billing.Subscription, _Mapping]] = ..., upcoming: _Optional[_Union[_billing_pb2.Billing.Subscription, _Mapping]] = ...) -> None: ...

class CreateSubscriptionInput(_message.Message):
    __slots__ = ("plan_id", "variant_id", "seats")
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    variant_id: str
    seats: int
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ...) -> None: ...

class CreateSubscriptionOutput(_message.Message):
    __slots__ = ("checkout_url",)
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    def __init__(self, checkout_url: _Optional[str] = ...) -> None: ...

class UpdateSubscriptionInput(_message.Message):
    __slots__ = ("plan_id", "variant_id", "seats")
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    variant_id: str
    seats: int
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ...) -> None: ...

class UpdateSubscriptionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CancelSubscriptionInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CancelSubscriptionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StartSubscriptionTrialInput(_message.Message):
    __slots__ = ("plan_id", "variant_id")
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    variant_id: str
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ...) -> None: ...

class StartSubscriptionTrialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EndSubscriptionTrialInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EndSubscriptionTrialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SimulateSubscriptionInput(_message.Message):
    __slots__ = ("plan_id", "variant_id", "seats", "coupon")
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    COUPON_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    variant_id: str
    seats: int
    coupon: str
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ..., coupon: _Optional[str] = ...) -> None: ...

class SimulateSubscriptionOutput(_message.Message):
    __slots__ = ("due", "invoice")
    DUE_FIELD_NUMBER: _ClassVar[int]
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    due: _invoice_pb2.Invoice
    invoice: _invoice_pb2.Invoice
    def __init__(self, due: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ..., invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class CreatePortalLinkInput(_message.Message):
    __slots__ = ("flow", "back_url", "return_url")
    FLOW_FIELD_NUMBER: _ClassVar[int]
    BACK_URL_FIELD_NUMBER: _ClassVar[int]
    RETURN_URL_FIELD_NUMBER: _ClassVar[int]
    flow: str
    back_url: str
    return_url: str
    def __init__(self, flow: _Optional[str] = ..., back_url: _Optional[str] = ..., return_url: _Optional[str] = ...) -> None: ...

class CreatePortalLinkOutput(_message.Message):
    __slots__ = ("portal_link",)
    PORTAL_LINK_FIELD_NUMBER: _ClassVar[int]
    portal_link: str
    def __init__(self, portal_link: _Optional[str] = ...) -> None: ...

class UpcomingInvoiceInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpcomingInvoiceOutput(_message.Message):
    __slots__ = ("invoice",)
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class DescribeInvoiceInput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class DescribeInvoiceOutput(_message.Message):
    __slots__ = ("invoice",)
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class PayInvoiceInput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class PayInvoiceOutput(_message.Message):
    __slots__ = ("checkout_url",)
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    def __init__(self, checkout_url: _Optional[str] = ...) -> None: ...

class ListInvoicesInput(_message.Message):
    __slots__ = ("size", "after", "before")
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    size: int
    after: str
    before: str
    def __init__(self, size: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ...) -> None: ...

class ListInvoicesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_invoice_pb2.Invoice]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_invoice_pb2.Invoice, _Mapping]]] = ...) -> None: ...

class ListAvailablePlansInput(_message.Message):
    __slots__ = ("offset", "size", "locale", "currency", "extra")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    locale: str
    currency: str
    extra: _containers.RepeatedScalarFieldContainer[_plan_pb2.Plan.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., locale: _Optional[str] = ..., currency: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_plan_pb2.Plan.Extra, str]]] = ...) -> None: ...

class ListAvailablePlansOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_plan_pb2.Plan, _Mapping]]] = ...) -> None: ...



from .auto_reply_service_http import *
from .ticket_service_http import *
from .auto_reply_pb2 import *
from .ticket_pb2 import *
from .ticket_service_pb2 import *
from .events_pb2 import *
from .auto_reply_service_pb2 import *
from .support_pb2 import *
from .support_http import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/stress_task.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/stress_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import script_pb2 as eolymp_dot_executor_dot_script__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/executor/stress_task.proto\x12\x0f\x65olymp.executor\x1a\x1c\x65olymp/executor/script.proto\"\xef\x03\n\nStressTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12;\n\x08metadata\x18\x05 \x03(\x0b\x32).eolymp.executor.StressTask.MetadataEntry\x12\x17\n\x0fwall_time_limit\x18\n \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18\x0b \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0c \x01(\x04\x12\x17\n\x0fiteration_count\x18\x0f \x01(\r\x12\x11\n\trun_count\x18\x10 \x01(\r\x12\x1c\n\x14interactive_followup\x18\x11 \x01(\x08\x12+\n\ninteractor\x18\x19 \x01(\x0b\x32\x17.eolymp.executor.Script\x12*\n\tvalidator\x18\x1a \x01(\x0b\x32\x17.eolymp.executor.Script\x12*\n\tgenerator\x18\x1b \x01(\x0b\x32\x17.eolymp.executor.Script\x12)\n\x08solution\x18\x1c \x01(\x0b\x32\x17.eolymp.executor.Script\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.stress_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_STRESSTASK_METADATAENTRY']._loaded_options = None
  _globals['_STRESSTASK_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_STRESSTASK']._serialized_start=85
  _globals['_STRESSTASK']._serialized_end=580
  _globals['_STRESSTASK_METADATAENTRY']._serialized_start=533
  _globals['_STRESSTASK_METADATAENTRY']._serialized_end=580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/penalty_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/penalty_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import penalty_pb2 as eolymp_dot_community_dot_penalty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/community/penalty_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/community/penalty.proto\"U\n\x12\x43reatePenaltyInput\x12*\n\x07penalty\x18\x01 \x01(\x0b\x32\x19.eolymp.community.Penalty\x12\x13\n\x0b\x64ont_notify\x18\x02 \x01(\x08\")\n\x13\x43reatePenaltyOutput\x12\x12\n\npenalty_id\x18\x01 \x01(\t\"\xda\x01\n\x12UpdatePenaltyInput\x12\x39\n\x05patch\x18\x03 \x03(\x0e\x32*.eolymp.community.UpdatePenaltyInput.Patch\x12\x12\n\npenalty_id\x18\x01 \x01(\t\x12*\n\x07penalty\x18\x02 \x01(\x0b\x32\x19.eolymp.community.Penalty\"I\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07SUMMARY\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\x12\t\n\x05SCOPE\x10\x03\x12\x0e\n\nEXPIRES_AT\x10\x04\"\x15\n\x13UpdatePenaltyOutput\"(\n\x12\x44\x65letePenaltyInput\x12\x12\n\npenalty_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65letePenaltyOutput\"[\n\x14\x44\x65scribePenaltyInput\x12\x12\n\npenalty_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.community.Penalty.Extra\"C\n\x15\x44\x65scribePenaltyOutput\x12*\n\x07penalty\x18\x01 \x01(\x0b\x32\x19.eolymp.community.Penalty\"c\n\x12ListPenaltiesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.community.Penalty.Extra\"N\n\x13ListPenaltiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.community.Penalty2\xdb\x06\n\x0ePenaltyService\x12\x9d\x01\n\rCreatePenalty\x12$.eolymp.community.CreatePenaltyInput\x1a%.eolymp.community.CreatePenaltyOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x0c\"\n/penalties\x12\xaa\x01\n\rUpdatePenalty\x12$.eolymp.community.UpdatePenaltyInput\x1a%.eolymp.community.UpdatePenaltyOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x19\"\x17/penalties/{penalty_id}\x12\xaa\x01\n\rDeletePenalty\x12$.eolymp.community.DeletePenaltyInput\x1a%.eolymp.community.DeletePenaltyOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x19*\x17/penalties/{penalty_id}\x12\xaf\x01\n\x0f\x44\x65scribePenalty\x12&.eolymp.community.DescribePenaltyInput\x1a\'.eolymp.community.DescribePenaltyOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x19\x12\x17/penalties/{penalty_id}\x12\x9c\x01\n\rListPenalties\x12$.eolymp.community.ListPenaltiesInput\x1a%.eolymp.community.ListPenaltiesOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0c\x12\n/penaltiesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.penalty_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_PENALTYSERVICE'].methods_by_name['CreatePenalty']._loaded_options = None
  _globals['_PENALTYSERVICE'].methods_by_name['CreatePenalty']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\014\"\n/penalties'
  _globals['_PENALTYSERVICE'].methods_by_name['UpdatePenalty']._loaded_options = None
  _globals['_PENALTYSERVICE'].methods_by_name['UpdatePenalty']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\031\"\027/penalties/{penalty_id}'
  _globals['_PENALTYSERVICE'].methods_by_name['DeletePenalty']._loaded_options = None
  _globals['_PENALTYSERVICE'].methods_by_name['DeletePenalty']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\031*\027/penalties/{penalty_id}'
  _globals['_PENALTYSERVICE'].methods_by_name['DescribePenalty']._loaded_options = None
  _globals['_PENALTYSERVICE'].methods_by_name['DescribePenalty']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\031\022\027/penalties/{penalty_id}'
  _globals['_PENALTYSERVICE'].methods_by_name['ListPenalties']._loaded_options = None
  _globals['_PENALTYSERVICE'].methods_by_name['ListPenalties']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\014\022\n/penalties'
  _globals['_CREATEPENALTYINPUT']._serialized_start=191
  _globals['_CREATEPENALTYINPUT']._serialized_end=276
  _globals['_CREATEPENALTYOUTPUT']._serialized_start=278
  _globals['_CREATEPENALTYOUTPUT']._serialized_end=319
  _globals['_UPDATEPENALTYINPUT']._serialized_start=322
  _globals['_UPDATEPENALTYINPUT']._serialized_end=540
  _globals['_UPDATEPENALTYINPUT_PATCH']._serialized_start=467
  _globals['_UPDATEPENALTYINPUT_PATCH']._serialized_end=540
  _globals['_UPDATEPENALTYOUTPUT']._serialized_start=542
  _globals['_UPDATEPENALTYOUTPUT']._serialized_end=563
  _globals['_DELETEPENALTYINPUT']._serialized_start=565
  _globals['_DELETEPENALTYINPUT']._serialized_end=605
  _globals['_DELETEPENALTYOUTPUT']._serialized_start=607
  _globals['_DELETEPENALTYOUTPUT']._serialized_end=628
  _globals['_DESCRIBEPENALTYINPUT']._serialized_start=630
  _globals['_DESCRIBEPENALTYINPUT']._serialized_end=721
  _globals['_DESCRIBEPENALTYOUTPUT']._serialized_start=723
  _globals['_DESCRIBEPENALTYOUTPUT']._serialized_end=790
  _globals['_LISTPENALTIESINPUT']._serialized_start=792
  _globals['_LISTPENALTIESINPUT']._serialized_end=891
  _globals['_LISTPENALTIESOUTPUT']._serialized_start=893
  _globals['_LISTPENALTIESOUTPUT']._serialized_end=971
  _globals['_PENALTYSERVICE']._serialized_start=974
  _globals['_PENALTYSERVICE']._serialized_end=1833
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/session.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/community/session.proto\x12\x10\x65olymp.community\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc4\x01\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nuser_agent\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x12\n\nip_address\x18\n \x01(\t\x12\x31\n\rfirst_seen_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_seen_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_SESSION']._serialized_start=86
  _globals['_SESSION']._serialized_end=282
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import course_pb2 as _course_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListCoursesInput(_message.Message):
    __slots__ = ("offset", "size", "search", "filters", "sort", "order", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListCoursesInput.Sortable]
    DEFAULT: ListCoursesInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "topic_id", "locale")
        ID_FIELD_NUMBER: _ClassVar[int]
        TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        topic_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., topic_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    search: str
    filters: ListCoursesInput.Filter
    sort: ListCoursesInput.Sortable
    order: _direction_pb2.Direction
    extra: _containers.RepeatedScalarFieldContainer[_course_pb2.Course.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListCoursesInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListCoursesInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_course_pb2.Course.Extra, str]]] = ...) -> None: ...

class ListCoursesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_course_pb2.Course]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_course_pb2.Course, _Mapping]]] = ...) -> None: ...

class DescribeCourseInput(_message.Message):
    __slots__ = ("course_id", "extra")
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    extra: _containers.RepeatedScalarFieldContainer[_course_pb2.Course.Extra]
    def __init__(self, course_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_course_pb2.Course.Extra, str]]] = ...) -> None: ...

class DescribeCourseOutput(_message.Message):
    __slots__ = ("course",)
    COURSE_FIELD_NUMBER: _ClassVar[int]
    course: _course_pb2.Course
    def __init__(self, course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class CreateCourseInput(_message.Message):
    __slots__ = ("course",)
    COURSE_FIELD_NUMBER: _ClassVar[int]
    course: _course_pb2.Course
    def __init__(self, course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class CreateCourseOutput(_message.Message):
    __slots__ = ("course_id",)
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    def __init__(self, course_id: _Optional[str] = ...) -> None: ...

class UpdateCourseInput(_message.Message):
    __slots__ = ("patch", "course_id", "course")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateCourseInput.Patch]
        LOCALE: _ClassVar[UpdateCourseInput.Patch]
        NAME: _ClassVar[UpdateCourseInput.Patch]
        DESCRIPTION: _ClassVar[UpdateCourseInput.Patch]
        IMAGE: _ClassVar[UpdateCourseInput.Patch]
        VISIBILITY: _ClassVar[UpdateCourseInput.Patch]
        DURATION: _ClassVar[UpdateCourseInput.Patch]
        TOPICS: _ClassVar[UpdateCourseInput.Patch]
    ALL: UpdateCourseInput.Patch
    LOCALE: UpdateCourseInput.Patch
    NAME: UpdateCourseInput.Patch
    DESCRIPTION: UpdateCourseInput.Patch
    IMAGE: UpdateCourseInput.Patch
    VISIBILITY: UpdateCourseInput.Patch
    DURATION: UpdateCourseInput.Patch
    TOPICS: UpdateCourseInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    COURSE_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateCourseInput.Patch]
    course_id: str
    course: _course_pb2.Course
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateCourseInput.Patch, str]]] = ..., course_id: _Optional[str] = ..., course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class UpdateCourseOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteCourseInput(_message.Message):
    __slots__ = ("course_id",)
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    def __init__(self, course_id: _Optional[str] = ...) -> None: ...

class DeleteCourseOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CopyCourseInput(_message.Message):
    __slots__ = ("course_id", "copy_scope", "copy_name")
    class Scope(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[CopyCourseInput.Scope]
        MODULES: _ClassVar[CopyCourseInput.Scope]
        STUDENTS: _ClassVar[CopyCourseInput.Scope]
        ASSIGNMENTS: _ClassVar[CopyCourseInput.Scope]
        PERMISSIONS: _ClassVar[CopyCourseInput.Scope]
    ALL: CopyCourseInput.Scope
    MODULES: CopyCourseInput.Scope
    STUDENTS: CopyCourseInput.Scope
    ASSIGNMENTS: CopyCourseInput.Scope
    PERMISSIONS: CopyCourseInput.Scope
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    COPY_SCOPE_FIELD_NUMBER: _ClassVar[int]
    COPY_NAME_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    copy_scope: _containers.RepeatedScalarFieldContainer[CopyCourseInput.Scope]
    copy_name: str
    def __init__(self, course_id: _Optional[str] = ..., copy_scope: _Optional[_Iterable[_Union[CopyCourseInput.Scope, str]]] = ..., copy_name: _Optional[str] = ...) -> None: ...

class CopyCourseOutput(_message.Message):
    __slots__ = ("copy_course_id",)
    COPY_COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    copy_course_id: str
    def __init__(self, copy_course_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/security_event.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/security_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/auth/security_event.proto\x12\x0b\x65olymp.auth\"\xb7\x03\n\rSecurityEvent\x12\x42\n\x0esession_closed\x18\x01 \x01(\x0b\x32(.eolymp.auth.SecurityEvent.SessionClosedH\x00\x12@\n\rtoken_revoked\x18\x02 \x01(\x0b\x32\'.eolymp.auth.SecurityEvent.TokenRevokedH\x00\x12\x42\n\x0e\x61\x63\x63ount_purged\x18\x03 \x01(\x0b\x32(.eolymp.auth.SecurityEvent.AccountPurgedH\x00\x1a\x44\n\rSessionClosed\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a[\n\x0cTokenRevoked\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x12\n\ntoken_type\x18\x03 \x01(\t\x12\x16\n\x0etoken_hash_md5\x18\x04 \x01(\t\x1a\x30\n\rAccountPurged\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\tB\x07\n\x05\x65ventB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.security_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_SECURITYEVENT']._serialized_start=50
  _globals['_SECURITYEVENT']._serialized_end=489
  _globals['_SECURITYEVENT_SESSIONCLOSED']._serialized_start=269
  _globals['_SECURITYEVENT_SESSIONCLOSED']._serialized_end=337
  _globals['_SECURITYEVENT_TOKENREVOKED']._serialized_start=339
  _globals['_SECURITYEVENT_TOKENREVOKED']._serialized_end=430
  _globals['_SECURITYEVENT_ACCOUNTPURGED']._serialized_start=432
  _globals['_SECURITYEVENT_ACCOUNTPURGED']._serialized_end=480
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Certificate(_message.Message):
    __slots__ = ("id", "member_id", "target_id", "verification_url", "download_url", "html_url", "locale", "type", "attributes", "issued_at", "expires_at")
    class AttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_ID_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_URL_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    HTML_URL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    ISSUED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    member_id: str
    target_id: str
    verification_url: str
    download_url: str
    html_url: str
    locale: str
    type: str
    attributes: _containers.ScalarMap[str, str]
    issued_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., target_id: _Optional[str] = ..., verification_url: _Optional[str] = ..., download_url: _Optional[str] = ..., html_url: _Optional[str] = ..., locale: _Optional[str] = ..., type: _Optional[str] = ..., attributes: _Optional[_Mapping[str, str]] = ..., issued_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/translation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/translation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/l10n/translation.proto\x12\x0b\x65olymp.l10n\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaf\x02\n\x0bTranslation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12/\n\x06status\x18\x04 \x01(\x0e\x32\x1f.eolymp.l10n.Translation.Status\x12\x14\n\x0cneeds_review\x18\x05 \x01(\x08\x12\x12\n\ncreated_by\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61pproved_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"7\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\n\n\x06UNUSED\x10\x04\x42+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.translation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_TRANSLATION']._serialized_start=80
  _globals['_TRANSLATION']._serialized_end=383
  _globals['_TRANSLATION_STATUS']._serialized_start=328
  _globals['_TRANSLATION_STATUS']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/product_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/product_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import product_pb2 as eolymp_dot_commerce_dot_product__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/commerce/product_service.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/commerce/product.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"?\n\x12\x43reateProductInput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\")\n\x13\x43reateProductOutput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x88\x01\n\x12UpdateProductInput\x12\x33\n\x05patch\x18\x03 \x03(\x0e\x32$.eolymp.commerce.Product.Patch.Field\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12)\n\x07product\x18\x02 \x01(\x0b\x32\x18.eolymp.commerce.Product\"\x15\n\x13UpdateProductOutput\"(\n\x12\x44\x65leteProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProductOutput\"q\n\x14\x44\x65scribeProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.commerce.Product.Extra.Field\"B\n\x15\x44\x65scribeProductOutput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\"\x95\x04\n\x11ListProductsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.commerce.ListProductsInput.Filter\x12\x39\n\x04sort\x18\x32 \x01(\x0e\x32+.eolymp.commerce.ListProductsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.commerce.Product.Extra.Field\x1a\xce\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x36\n\x0cout_of_stock\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x05price\x18\x04 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"L\n\x12ListProductsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.commerce.Product2\xe7\x06\n\x0eProductService\x12\xa0\x01\n\rCreateProduct\x12#.eolymp.commerce.CreateProductInput\x1a$.eolymp.commerce.CreateProductOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x11\"\x0f/store/products\x12\xad\x01\n\rUpdateProduct\x12#.eolymp.commerce.UpdateProductInput\x1a$.eolymp.commerce.UpdateProductOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/store/products/{product_id}\x12\xad\x01\n\rDeleteProduct\x12#.eolymp.commerce.DeleteProductInput\x1a$.eolymp.commerce.DeleteProductOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x1e*\x1c/store/products/{product_id}\x12\xb2\x01\n\x0f\x44\x65scribeProduct\x12%.eolymp.commerce.DescribeProductInput\x1a&.eolymp.commerce.DescribeProductOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:catalog:read\x82\xd3\xe4\x93\x02\x1e\"\x1c/store/products/{product_id}\x12\x9c\x01\n\x0cListProducts\x12\".eolymp.commerce.ListProductsInput\x1a#.eolymp.commerce.ListProductsOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:catalog:read\x82\xd3\xe4\x93\x02\x11\x12\x0f/store/productsB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_PRODUCTSERVICE'].methods_by_name['CreateProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['CreateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\021\"\017/store/products'
  _globals['_PRODUCTSERVICE'].methods_by_name['UpdateProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['UpdateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\036\032\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['DeleteProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['DeleteProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\036*\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['DescribeProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['DescribeProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025commerce:catalog:read\202\323\344\223\002\036\"\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['ListProducts']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['ListProducts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025commerce:catalog:read\202\323\344\223\002\021\022\017/store/products'
  _globals['_CREATEPRODUCTINPUT']._serialized_start=257
  _globals['_CREATEPRODUCTINPUT']._serialized_end=320
  _globals['_CREATEPRODUCTOUTPUT']._serialized_start=322
  _globals['_CREATEPRODUCTOUTPUT']._serialized_end=363
  _globals['_UPDATEPRODUCTINPUT']._serialized_start=366
  _globals['_UPDATEPRODUCTINPUT']._serialized_end=502
  _globals['_UPDATEPRODUCTOUTPUT']._serialized_start=504
  _globals['_UPDATEPRODUCTOUTPUT']._serialized_end=525
  _globals['_DELETEPRODUCTINPUT']._serialized_start=527
  _globals['_DELETEPRODUCTINPUT']._serialized_end=567
  _globals['_DELETEPRODUCTOUTPUT']._serialized_start=569
  _globals['_DELETEPRODUCTOUTPUT']._serialized_end=590
  _globals['_DESCRIBEPRODUCTINPUT']._serialized_start=592
  _globals['_DESCRIBEPRODUCTINPUT']._serialized_end=705
  _globals['_DESCRIBEPRODUCTOUTPUT']._serialized_start=707
  _globals['_DESCRIBEPRODUCTOUTPUT']._serialized_end=773
  _globals['_LISTPRODUCTSINPUT']._serialized_start=776
  _globals['_LISTPRODUCTSINPUT']._serialized_end=1309
  _globals['_LISTPRODUCTSINPUT_FILTER']._serialized_start=1078
  _globals['_LISTPRODUCTSINPUT_FILTER']._serialized_end=1284
  _globals['_LISTPRODUCTSINPUT_SORTABLE']._serialized_start=1286
  _globals['_LISTPRODUCTSINPUT_SORTABLE']._serialized_end=1309
  _globals['_LISTPRODUCTSOUTPUT']._serialized_start=1311
  _globals['_LISTPRODUCTSOUTPUT']._serialized_end=1387
  _globals['_PRODUCTSERVICE']._serialized_start=1390
  _globals['_PRODUCTSERVICE']._serialized_end=2261
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/achievement_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/achievement_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import achievement_pb2 as eolymp_dot_community_dot_achievement__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/community/achievement_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/community/achievement.proto\x1a!eolymp/wellknown/expression.proto\"`\n\x16\x41ssignAchievementInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x02 \x01(\t\x12\x10\n\x06set_to\x18\x03 \x01(\x05H\x00\x12\x10\n\x06inc_by\x18\x04 \x01(\x05H\x00\x42\n\n\x08quantity\"+\n\x17\x41ssignAchievementOutput\x12\x10\n\x08quantity\x18\x03 \x01(\x05\"2\n\x18UnassignAchievementInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x02 \x01(\t\"\x1b\n\x19UnassignAchievementOutput\"\x8f\x02\n\x15ListAchievementsInput\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12?\n\x07\x66ilters\x18( \x01(\x0b\x32..eolymp.community.ListAchievementsInput.Filter\x12\x33\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32#.eolymp.community.Achievement.Extra\x1a\x43\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"o\n\x16ListAchievementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.community.Achievement2\xc5\x04\n\x12\x41\x63hievementService\x12\xbd\x01\n\x11\x41ssignAchievement\x12(.eolymp.community.AssignAchievementInput\x1a).eolymp.community.AssignAchievementOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02 \x1a\x1e/achievements/{achievement_id}\x12\xc3\x01\n\x13UnassignAchievement\x12*.eolymp.community.UnassignAchievementInput\x1a+.eolymp.community.UnassignAchievementOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02 *\x1e/achievements/{achievement_id}\x12\xa8\x01\n\x10ListAchievements\x12\'.eolymp.community.ListAchievementsInput\x1a(.eolymp.community.ListAchievementsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0f\x12\r/achievementsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.achievement_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['AssignAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['AssignAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002 \032\036/achievements/{achievement_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UnassignAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UnassignAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002 *\036/achievements/{achievement_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievements']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\017\022\r/achievements'
  _globals['_ASSIGNACHIEVEMENTINPUT']._serialized_start=234
  _globals['_ASSIGNACHIEVEMENTINPUT']._serialized_end=330
  _globals['_ASSIGNACHIEVEMENTOUTPUT']._serialized_start=332
  _globals['_ASSIGNACHIEVEMENTOUTPUT']._serialized_end=375
  _globals['_UNASSIGNACHIEVEMENTINPUT']._serialized_start=377
  _globals['_UNASSIGNACHIEVEMENTINPUT']._serialized_end=427
  _globals['_UNASSIGNACHIEVEMENTOUTPUT']._serialized_start=429
  _globals['_UNASSIGNACHIEVEMENTOUTPUT']._serialized_end=456
  _globals['_LISTACHIEVEMENTSINPUT']._serialized_start=459
  _globals['_LISTACHIEVEMENTSINPUT']._serialized_end=730
  _globals['_LISTACHIEVEMENTSINPUT_FILTER']._serialized_start=663
  _globals['_LISTACHIEVEMENTSINPUT_FILTER']._serialized_end=730
  _globals['_LISTACHIEVEMENTSOUTPUT']._serialized_start=732
  _globals['_LISTACHIEVEMENTSOUTPUT']._serialized_end=843
  _globals['_ACHIEVEMENTSERVICE']._serialized_start=846
  _globals['_ACHIEVEMENTSERVICE']._serialized_end=1427
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/webhook/delivery.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/webhook/delivery.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.webhook import webhook_pb2 as eolymp_dot_webhook_dot_webhook__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/webhook/delivery.proto\x12\x0e\x65olymp.webhook\x1a\x1c\x65olymp/webhook/webhook.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xae\x01\n\x08\x44\x65livery\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nwebhook_id\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x05\x65vent\x18\n \x01(\x0e\x32\x1d.eolymp.webhook.Webhook.Event\x12%\n\x07payload\x18\x0b \x01(\x0b\x32\x14.google.protobuf.AnyB1Z/github.com/eolymp/go-sdk/eolymp/webhook;webhookb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.webhook.delivery_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/webhook;webhook'
  _globals['_DELIVERY']._serialized_start=140
  _globals['_DELIVERY']._serialized_end=314
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.commerce import address_pb2 as _address_pb2
from eolymp.commerce import shopping_cart_pb2 as _shopping_cart_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeShoppingCartInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeShoppingCartOutput(_message.Message):
    __slots__ = ("cart",)
    CART_FIELD_NUMBER: _ClassVar[int]
    cart: _shopping_cart_pb2.ShoppingCart
    def __init__(self, cart: _Optional[_Union[_shopping_cart_pb2.ShoppingCart, _Mapping]] = ...) -> None: ...

class CreateShoppingCartItemInput(_message.Message):
    __slots__ = ("product_id", "variant_id", "quantity")
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    variant_id: str
    quantity: int
    def __init__(self, product_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., quantity: _Optional[int] = ...) -> None: ...

class CreateShoppingCartItemOutput(_message.Message):
    __slots__ = ("item_id",)
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    item_id: str
    def __init__(self, item_id: _Optional[str] = ...) -> None: ...

class UpdateShoppingCartItemInput(_message.Message):
    __slots__ = ("item_id", "quantity")
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    item_id: str
    quantity: int
    def __init__(self, item_id: _Optional[str] = ..., quantity: _Optional[int] = ...) -> None: ...

class UpdateShoppingCartItemOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteShoppingCartItemInput(_message.Message):
    __slots__ = ("item_id",)
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    item_id: str
    def __init__(self, item_id: _Optional[str] = ...) -> None: ...

class DeleteShoppingCartItemOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateShippingAddressInput(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: _address_pb2.Address
    def __init__(self, address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ...) -> None: ...

class UpdateShippingAddressOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateBillingAddressInput(_message.Message):
    __slots__ = ("address", "same_as_shipping")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SAME_AS_SHIPPING_FIELD_NUMBER: _ClassVar[int]
    address: _address_pb2.Address
    same_as_shipping: bool
    def __init__(self, address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., same_as_shipping: bool = ...) -> None: ...

class UpdateBillingAddressOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PlaceOrderInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PlaceOrderOutput(_message.Message):
    __slots__ = ("order_id", "order_number")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_NUMBER_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    order_number: str
    def __init__(self, order_id: _Optional[str] = ..., order_number: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.ranker import activity_pb2 as _activity_pb2
from eolymp.ranker import scoreboard_pb2 as _scoreboard_pb2
from eolymp.ranker import scoreboard_service_pb2 as _scoreboard_service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListActivitiesInput(_message.Message):
    __slots__ = ("scoreboard_id", "offset", "size")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    offset: int
    size: int
    def __init__(self, scoreboard_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListActivitiesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_activity_pb2.Activity]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_activity_pb2.Activity, _Mapping]]] = ...) -> None: ...

class ScheduleActionInput(_message.Message):
    __slots__ = ("scoreboard_id", "action")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    action: _scoreboard_pb2.Scoreboard.Action
    def __init__(self, scoreboard_id: _Optional[str] = ..., action: _Optional[_Union[_scoreboard_pb2.Scoreboard.Action, _Mapping]] = ...) -> None: ...

class ScheduleActionOutput(_message.Message):
    __slots__ = ("action_id",)
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    action_id: str
    def __init__(self, action_id: _Optional[str] = ...) -> None: ...

class UnscheduleActionInput(_message.Message):
    __slots__ = ("scoreboard_id", "action_id")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    action_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., action_id: _Optional[str] = ...) -> None: ...

class UnscheduleActionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListScheduledActionsInput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class ListScheduledActionsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Action]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Action, _Mapping]]] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Activity(_message.Message):
    __slots__ = ("id", "type", "status", "scoreboard_id", "created_at", "started_at", "progress_at", "complete_at", "progress", "total", "error")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[Activity.Type]
        SCOREBOARD_REBUILD: _ClassVar[Activity.Type]
    NONE: Activity.Type
    SCOREBOARD_REBUILD: Activity.Type
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[Activity.Status]
        CREATED: _ClassVar[Activity.Status]
        STARTED: _ClassVar[Activity.Status]
        COMPLETE: _ClassVar[Activity.Status]
        ERROR: _ClassVar[Activity.Status]
    UNKNOWN: Activity.Status
    CREATED: Activity.Status
    STARTED: Activity.Status
    COMPLETE: Activity.Status
    ERROR: Activity.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_AT_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: Activity.Type
    status: Activity.Status
    scoreboard_id: str
    created_at: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    progress_at: _timestamp_pb2.Timestamp
    complete_at: _timestamp_pb2.Timestamp
    progress: int
    total: int
    error: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Activity.Type, str]] = ..., status: _Optional[_Union[Activity.Status, str]] = ..., scoreboard_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., progress_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., complete_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., progress: _Optional[int] = ..., total: _Optional[int] = ..., error: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PostType(_message.Message):
    __slots__ = ("id", "name", "hidden", "order", "variants")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[PostType.Extra]
        VARIANTS: _ClassVar[PostType.Extra]
    UNKNOWN_EXTRA: PostType.Extra
    VARIANTS: PostType.Extra
    class Variant(_message.Message):
        __slots__ = ("locale", "name")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        locale: str
        name: str
        def __init__(self, locale: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hidden: bool
    order: int
    variants: _containers.RepeatedCompositeFieldContainer[PostType.Variant]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hidden: bool = ..., order: _Optional[int] = ..., variants: _Optional[_Iterable[_Union[PostType.Variant, _Mapping]]] = ...) -> None: ...



import datetime

from eolymp.commerce import address_pb2 as _address_pb2
from eolymp.universe import plan_pb2 as _plan_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Billing(_message.Message):
    __slots__ = ()
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Billing.Status]
        TRIAL: _ClassVar[Billing.Status]
        ACTIVE: _ClassVar[Billing.Status]
        CANCELLED: _ClassVar[Billing.Status]
    UNKNOWN_STATUS: Billing.Status
    TRIAL: Billing.Status
    ACTIVE: Billing.Status
    CANCELLED: Billing.Status
    class Recurrence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_RECURRENCE: _ClassVar[Billing.Recurrence]
        MONTHLY: _ClassVar[Billing.Recurrence]
        YEARLY: _ClassVar[Billing.Recurrence]
    UNKNOWN_RECURRENCE: Billing.Recurrence
    MONTHLY: Billing.Recurrence
    YEARLY: Billing.Recurrence
    class Information(_message.Message):
        __slots__ = ("name", "email", "phone", "tax_id_type", "tax_id_value", "address", "currency", "language")
        NAME_FIELD_NUMBER: _ClassVar[int]
        EMAIL_FIELD_NUMBER: _ClassVar[int]
        PHONE_FIELD_NUMBER: _ClassVar[int]
        TAX_ID_TYPE_FIELD_NUMBER: _ClassVar[int]
        TAX_ID_VALUE_FIELD_NUMBER: _ClassVar[int]
        ADDRESS_FIELD_NUMBER: _ClassVar[int]
        CURRENCY_FIELD_NUMBER: _ClassVar[int]
        LANGUAGE_FIELD_NUMBER: _ClassVar[int]
        name: str
        email: str
        phone: str
        tax_id_type: str
        tax_id_value: str
        address: _address_pb2.Address
        currency: str
        language: str
        def __init__(self, name: _Optional[str] = ..., email: _Optional[str] = ..., phone: _Optional[str] = ..., tax_id_type: _Optional[str] = ..., tax_id_value: _Optional[str] = ..., address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., currency: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...
    class Subscription(_message.Message):
        __slots__ = ("id", "status", "irregular", "has_payment_method", "plan", "variant", "seats", "created_at", "started_at", "cancel_at", "cancelled_at", "ended_at", "period_start", "period_end", "trial_start", "trial_end")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        IRREGULAR_FIELD_NUMBER: _ClassVar[int]
        HAS_PAYMENT_METHOD_FIELD_NUMBER: _ClassVar[int]
        PLAN_FIELD_NUMBER: _ClassVar[int]
        VARIANT_FIELD_NUMBER: _ClassVar[int]
        SEATS_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        STARTED_AT_FIELD_NUMBER: _ClassVar[int]
        CANCEL_AT_FIELD_NUMBER: _ClassVar[int]
        CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
        ENDED_AT_FIELD_NUMBER: _ClassVar[int]
        PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        TRIAL_START_FIELD_NUMBER: _ClassVar[int]
        TRIAL_END_FIELD_NUMBER: _ClassVar[int]
        id: str
        status: Billing.Status
        irregular: bool
        has_payment_method: bool
        plan: _plan_pb2.Plan
        variant: _plan_pb2.Plan.Variant
        seats: int
        created_at: _timestamp_pb2.Timestamp
        started_at: _timestamp_pb2.Timestamp
        cancel_at: _timestamp_pb2.Timestamp
        cancelled_at: _timestamp_pb2.Timestamp
        ended_at: _timestamp_pb2.Timestamp
        period_start: _timestamp_pb2.Timestamp
        period_end: _timestamp_pb2.Timestamp
        trial_start: _timestamp_pb2.Timestamp
        trial_end: _timestamp_pb2.Timestamp
        def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Billing.Status, str]] = ..., irregular: bool = ..., has_payment_method: bool = ..., plan: _Optional[_Union[_plan_pb2.Plan, _Mapping]] = ..., variant: _Optional[_Union[_plan_pb2.Plan.Variant, _Mapping]] = ..., seats: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., cancel_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., ended_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., trial_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., trial_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...



from .post_type_service_http import *
from .post_service_http import *
from .post_type_pb2 import *
from .message_service_pb2 import *
from .thread_pb2 import *
from .subscription_service_pb2 import *
from .subscription_service_http import *
from .message_pb2 import *
from .thread_endpoint_http import *
from .configuration_pb2 import *
from .subscription_pb2 import *
from .thread_endpoint_pb2 import *
from .post_service_pb2 import *
from .configuration_service_http import *
from .message_service_http import *
from .post_type_service_pb2 import *
from .configuration_service_pb2 import *
from .post_pb2 import *



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Product(_message.Message):
    __slots__ = ("id", "name", "description", "images", "out_of_stock", "currency", "unit_price", "attributes", "variants")
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_FIELD: _ClassVar[Product.Extra.Field]
            DESCRIPTION_VALUE: _ClassVar[Product.Extra.Field]
            DESCRIPTION_RENDER: _ClassVar[Product.Extra.Field]
            ATTRIBUTES: _ClassVar[Product.Extra.Field]
            VARIANTS: _ClassVar[Product.Extra.Field]
        UNKNOWN_FIELD: Product.Extra.Field
        DESCRIPTION_VALUE: Product.Extra.Field
        DESCRIPTION_RENDER: Product.Extra.Field
        ATTRIBUTES: Product.Extra.Field
        VARIANTS: Product.Extra.Field
        def __init__(self) -> None: ...
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_FIELD: _ClassVar[Product.Patch.Field]
            ALL: _ClassVar[Product.Patch.Field]
            NAME: _ClassVar[Product.Patch.Field]
            DESCRIPTION: _ClassVar[Product.Patch.Field]
            IMAGES: _ClassVar[Product.Patch.Field]
            UNIT_PRICE: _ClassVar[Product.Patch.Field]
            ATTRIBUTES: _ClassVar[Product.Patch.Field]
            VARIANTS: _ClassVar[Product.Patch.Field]
        UNKNOWN_FIELD: Product.Patch.Field
        ALL: Product.Patch.Field
        NAME: Product.Patch.Field
        DESCRIPTION: Product.Patch.Field
        IMAGES: Product.Patch.Field
        UNIT_PRICE: Product.Patch.Field
        ATTRIBUTES: Product.Patch.Field
        VARIANTS: Product.Patch.Field
        def __init__(self) -> None: ...
    class Attribute(_message.Message):
        __slots__ = ("key", "label")
        KEY_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        key: str
        label: str
        def __init__(self, key: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...
    class Variant(_message.Message):
        __slots__ = ("id", "values", "images", "out_of_stock")
        class ValuesEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        IMAGES_FIELD_NUMBER: _ClassVar[int]
        OUT_OF_STOCK_FIELD_NUMBER: _ClassVar[int]
        id: str
        values: _containers.ScalarMap[str, str]
        images: _containers.RepeatedScalarFieldContainer[str]
        out_of_stock: bool
        def __init__(self, id: _Optional[str] = ..., values: _Optional[_Mapping[str, str]] = ..., images: _Optional[_Iterable[str]] = ..., out_of_stock: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IMAGES_FIELD_NUMBER: _ClassVar[int]
    OUT_OF_STOCK_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    UNIT_PRICE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: _content_pb2.Content
    images: _containers.RepeatedScalarFieldContainer[str]
    out_of_stock: bool
    currency: str
    unit_price: int
    attributes: _containers.RepeatedCompositeFieldContainer[Product.Attribute]
    variants: _containers.RepeatedCompositeFieldContainer[Product.Variant]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., images: _Optional[_Iterable[str]] = ..., out_of_stock: bool = ..., currency: _Optional[str] = ..., unit_price: _Optional[int] = ..., attributes: _Optional[_Iterable[_Union[Product.Attribute, _Mapping]]] = ..., variants: _Optional[_Iterable[_Union[Product.Variant, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/subscription.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/subscription.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/subscription.proto\x12\x11\x65olymp.discussion\"}\n\x0cSubscription\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.eolymp.discussion.Subscription.Type\"9\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05MUTED\x10\x01\x12\x0e\n\nSUBSCRIBED\x10\x02\x12\x0c\n\x08WATCHING\x10\x03\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.subscription_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_SUBSCRIPTION']._serialized_start=59
  _globals['_SUBSCRIPTION']._serialized_end=184
  _globals['_SUBSCRIPTION_TYPE']._serialized_start=127
  _globals['_SUBSCRIPTION_TYPE']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/module_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/module_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/module_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/module.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\":\n\x11\x43reateModuleInput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\'\n\x12\x43reateModuleOutput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\xed\x01\n\x11UpdateModuleInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateModuleInput.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12%\n\x06module\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"g\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\t\n\x05\x45XTRA\x10\x06\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\x12\n\n\x06WEIGHT\x10\x07\"\x14\n\x12UpdateModuleOutput\"&\n\x11\x44\x65leteModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteModuleOutput\"\x8a\x01\n\x13\x44\x65scribeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x13\n\tmember_id\x18\x02 \x01(\tH\x00\x12\x12\n\x08group_id\x18\x03 \x01(\tH\x00\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.ExtraB\n\n\x08\x61ssignee\"=\n\x14\x44\x65scribeModuleOutput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\x9e\x04\n\x10ListModulesInput\x12\x13\n\tmember_id\x18\x05 \x01(\tH\x00\x12\x12\n\x08group_id\x18\x06 \x01(\tH\x00\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListModulesInput.Filter\x12\x32\n\x04sort\x18\x32 \x01(\x0e\x32$.eolymp.course.ListModulesInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\x1a\xcd\x01\n\x06\x46ilter\x12/\n\x05\x64raft\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x05\x65xtra\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06graded\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x06weight\x18\x05 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\x42\n\n\x08\x61ssignee\"H\n\x11ListModulesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Module\"%\n\x10StartModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x13\n\x11StartModuleOutput\"e\n\x10GradeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0f\n\x05grade\x18\x03 \x01(\rH\x00\x12\x11\n\x07\x65xcused\x18\x04 \x01(\x08H\x00\x42\x07\n\x05value\"\x13\n\x11GradeModuleOutput2\xce\x08\n\rModuleService\x12\x8f\x01\n\x0c\x43reateModule\x12 .eolymp.course.CreateModuleInput\x1a!.eolymp.course.CreateModuleOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\n\x1a\x08/modules\x12\x9b\x01\n\x0cUpdateModule\x12 .eolymp.course.UpdateModuleInput\x1a!.eolymp.course.UpdateModuleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/modules/{module_id}\x12\x9b\x01\n\x0c\x44\x65leteModule\x12 .eolymp.course.DeleteModuleInput\x1a!.eolymp.course.DeleteModuleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16*\x14/modules/{module_id}\x12\xa0\x01\n\x0e\x44\x65scribeModule\x12\".eolymp.course.DescribeModuleInput\x1a#.eolymp.course.DescribeModuleOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x16\x12\x14/modules/{module_id}\x12\x8b\x01\n\x0bListModules\x12\x1f.eolymp.course.ListModulesInput\x1a .eolymp.course.ListModulesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\n\x12\x08/modules\x12\x9d\x01\n\x0bStartModule\x12\x1f.eolymp.course.StartModuleInput\x1a .eolymp.course.StartModuleOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/start\x12\x9d\x01\n\x0bGradeModule\x12\x1f.eolymp.course.GradeModuleInput\x1a .eolymp.course.GradeModuleOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/gradeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_MODULESERVICE'].methods_by_name['CreateModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['CreateModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\n\032\010/modules'
  _globals['_MODULESERVICE'].methods_by_name['UpdateModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['UpdateModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026\032\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['DeleteModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['DeleteModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026*\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['DescribeModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['DescribeModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\026\022\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['ListModules']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['ListModules']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\n\022\010/modules'
  _globals['_MODULESERVICE'].methods_by_name['StartModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['StartModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\034\"\032/modules/{module_id}/start'
  _globals['_MODULESERVICE'].methods_by_name['GradeModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['GradeModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\034\"\032/modules/{module_id}/grade'
  _globals['_CREATEMODULEINPUT']._serialized_start=249
  _globals['_CREATEMODULEINPUT']._serialized_end=307
  _globals['_CREATEMODULEOUTPUT']._serialized_start=309
  _globals['_CREATEMODULEOUTPUT']._serialized_end=348
  _globals['_UPDATEMODULEINPUT']._serialized_start=351
  _globals['_UPDATEMODULEINPUT']._serialized_end=588
  _globals['_UPDATEMODULEINPUT_PATCH']._serialized_start=485
  _globals['_UPDATEMODULEINPUT_PATCH']._serialized_end=588
  _globals['_UPDATEMODULEOUTPUT']._serialized_start=590
  _globals['_UPDATEMODULEOUTPUT']._serialized_end=610
  _globals['_DELETEMODULEINPUT']._serialized_start=612
  _globals['_DELETEMODULEINPUT']._serialized_end=650
  _globals['_DELETEMODULEOUTPUT']._serialized_start=652
  _globals['_DELETEMODULEOUTPUT']._serialized_end=672
  _globals['_DESCRIBEMODULEINPUT']._serialized_start=675
  _globals['_DESCRIBEMODULEINPUT']._serialized_end=813
  _globals['_DESCRIBEMODULEOUTPUT']._serialized_start=815
  _globals['_DESCRIBEMODULEOUTPUT']._serialized_end=876
  _globals['_LISTMODULESINPUT']._serialized_start=879
  _globals['_LISTMODULESINPUT']._serialized_end=1421
  _globals['_LISTMODULESINPUT_FILTER']._serialized_start=1185
  _globals['_LISTMODULESINPUT_FILTER']._serialized_end=1390
  _globals['_LISTMODULESINPUT_SORT']._serialized_start=1392
  _globals['_LISTMODULESINPUT_SORT']._serialized_end=1409
  _globals['_LISTMODULESOUTPUT']._serialized_start=1423
  _globals['_LISTMODULESOUTPUT']._serialized_end=1495
  _globals['_STARTMODULEINPUT']._serialized_start=1497
  _globals['_STARTMODULEINPUT']._serialized_end=1534
  _globals['_STARTMODULEOUTPUT']._serialized_start=1536
  _globals['_STARTMODULEOUTPUT']._serialized_end=1555
  _globals['_GRADEMODULEINPUT']._serialized_start=1557
  _globals['_GRADEMODULEINPUT']._serialized_end=1658
  _globals['_GRADEMODULEOUTPUT']._serialized_start=1660
  _globals['_GRADEMODULEOUTPUT']._serialized_end=1679
  _globals['_MODULESERVICE']._serialized_start=1682
  _globals['_MODULESERVICE']._serialized_end=2784
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/printer/printer_connector.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/printer/printer_connector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.printer import printer_pb2 as eolymp_dot_printer_dot_printer__pb2
from eolymp.printer import printer_job_pb2 as eolymp_dot_printer_dot_printer__job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/printer/printer_connector.proto\x12\x0e\x65olymp.printer\x1a\x1c\x65olymp/printer/printer.proto\x1a eolymp/printer/printer_job.proto\"\xb6\x02\n\x1dPrinterConnectorClientMessage\x12\x46\n\x06status\x18\x65 \x01(\x0b\x32\x34.eolymp.printer.PrinterConnectorClientMessage.StatusH\x00\x12\x46\n\x06report\x18\x66 \x01(\x0b\x32\x34.eolymp.printer.PrinterConnectorClientMessage.ReportH\x00\x1a@\n\x06Report\x12\n\n\x02id\x18\x02 \x01(\t\x12*\n\x06status\x18\x01 \x01(\x0e\x32\x1a.eolymp.printer.Job.Status\x1a\x38\n\x06Status\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.eolymp.printer.Printer.StatusB\t\n\x07message\"\xa5\x02\n\x1dPrinterConnectorServerMessage\x12\x44\n\x05hello\x18\x64 \x01(\x0b\x32\x33.eolymp.printer.PrinterConnectorServerMessage.HelloH\x00\x12\x44\n\x05print\x18n \x01(\x0b\x32\x33.eolymp.printer.PrinterConnectorServerMessage.PrintH\x00\x1a\x42\n\x05Hello\x12\x0f\n\x07\x63omment\x18\x01 \x01(\t\x12(\n\x07printer\x18\x02 \x01(\x0b\x32\x17.eolymp.printer.Printer\x1a)\n\x05Print\x12 \n\x03job\x18\x01 \x01(\x0b\x32\x13.eolymp.printer.JobB\t\n\x07message2\x81\x01\n\x10PrinterConnector\x12m\n\x07\x43onnect\x12-.eolymp.printer.PrinterConnectorClientMessage\x1a-.eolymp.printer.PrinterConnectorServerMessage\"\x00(\x01\x30\x01\x42\x31Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_connector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_PRINTERCONNECTORCLIENTMESSAGE']._serialized_start=123
  _globals['_PRINTERCONNECTORCLIENTMESSAGE']._serialized_end=433
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_REPORT']._serialized_start=300
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_REPORT']._serialized_end=364
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_STATUS']._serialized_start=366
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_STATUS']._serialized_end=422
  _globals['_PRINTERCONNECTORSERVERMESSAGE']._serialized_start=436
  _globals['_PRINTERCONNECTORSERVERMESSAGE']._serialized_end=729
  _globals['_PRINTERCONNECTORSERVERMESSAGE_HELLO']._serialized_start=609
  _globals['_PRINTERCONNECTORSERVERMESSAGE_HELLO']._serialized_end=675
  _globals['_PRINTERCONNECTORSERVERMESSAGE_PRINT']._serialized_start=677
  _globals['_PRINTERCONNECTORSERVERMESSAGE_PRINT']._serialized_end=718
  _globals['_PRINTERCONNECTOR']._serialized_start=732
  _globals['_PRINTERCONNECTOR']._serialized_end=861
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Translation(_message.Message):
    __slots__ = ("id", "locale", "message", "status", "needs_review", "created_by", "created_at", "approved_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[Translation.Status]
        PENDING: _ClassVar[Translation.Status]
        ACTIVE: _ClassVar[Translation.Status]
        UNUSED: _ClassVar[Translation.Status]
    NONE: Translation.Status
    PENDING: Translation.Status
    ACTIVE: Translation.Status
    UNUSED: Translation.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NEEDS_REVIEW_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    APPROVED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    locale: str
    message: str
    status: Translation.Status
    needs_review: bool
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    approved_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., message: _Optional[str] = ..., status: _Optional[_Union[Translation.Status, str]] = ..., needs_review: bool = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., approved_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.executor import script_pb2 as _script_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StressTask(_message.Message):
    __slots__ = ("task_id", "reference", "origin", "metadata", "wall_time_limit", "cpu_time_limit", "memory_limit", "iteration_count", "run_count", "interactive_followup", "interactor", "validator", "generator", "solution")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
    CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
    ITERATION_COUNT_FIELD_NUMBER: _ClassVar[int]
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    INTERACTIVE_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    GENERATOR_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    reference: str
    origin: str
    metadata: _containers.ScalarMap[str, str]
    wall_time_limit: int
    cpu_time_limit: int
    memory_limit: int
    iteration_count: int
    run_count: int
    interactive_followup: bool
    interactor: _script_pb2.Script
    validator: _script_pb2.Script
    generator: _script_pb2.Script
    solution: _script_pb2.Script
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., iteration_count: _Optional[int] = ..., run_count: _Optional[int] = ..., interactive_followup: bool = ..., interactor: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., validator: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., generator: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., solution: _Optional[_Union[_script_pb2.Script, _Mapping]] = ...) -> None: ...
